const { spawn, spawnSync, exec } = require('child_process')
const chalk = require('chalk')

const { TEMPLATES } = require('./question')
const { isYarn, CURR_DIR } = require('./helper')
const { updateTslintConfig } = require('./updateTslintConfig')
const { updatePackageJsonFile } = require('./updatePackageJsonFile')
const { copyFileToApp } = require('./copyFiles')
const { installCreateReactApp } = require('./installCreateReactApp')
const { installNecessaryPackages } = require('./installNecessaryPackages')
const { isExistApp } = require('./checkIsExistReactProject')

module.exports.createTypescriptProject = ({ name }) => {
  if (!name) {
    name = 'reactjs-ts-app'
  }
  name = `${CURR_DIR}/${name}`
  const TARGET_PATH = `${name}`

  if (!isExistApp) {
    installCreateReactApp({ isYarn, projectName: name })
  }

  // install necessary package
  installNecessaryPackages({ isYarn })

  // update tslint config
  console.log(chalk.green(`🥳 Config base URL ...`))
  updateTslintConfig()

  // Config scripts
  console.log(chalk.green(`🥳 Config scripts ...`))
  updatePackageJsonFile()

  // Run prepare
  console.log(chalk.green(`🥳 Run prepare ...`))
  spawnSync(isYarn ? 'yarn' : 'npm', ['run prepare'], {
    shell: true,
    stdio: 'inherit'
  })

  // copy files
  copyFileToApp({
    CURR_DIR,
    TARGET_PATH
  })
}
